import { system, world } from "@minecraft/server";

const DURABILITY_THRESHOLD = 5;

// Function to check item durability and send a warning
function checkDurability(player, item, slot) {
    const durability = item.getComponent("minecraft:durability");
    if (durability) {
        const maxDurability = durability.maxDurability;
        const currentDurability = durability.damage;
        if (maxDurability - currentDurability <= DURABILITY_THRESHOLD) {
            player.sendMessage(`§cWarning! Your ${item.typeId} in ${slot} is about to break!`);
        }
    }
}

// Monitor each player's inventory for low durability items
system.runInterval(() => {
    for (const player of world.getPlayers()) {
        try {
            const inventory = player.getComponent("minecraft:inventory")?.container;
            if (!inventory) continue;

            // Define slots to check
            const slots = {
                "main-hand": 0,
                "off-hand": 1,
                "helmet": 5,
                "chestplate": 6,
                "leggings": 7,
                "boots": 8
            };

            // Check durability for each slot
            for (const [slotName, slotIndex] of Object.entries(slots)) {
                const item = inventory.getItem(slotIndex);
                if (item) checkDurability(player, item, slotName);
            }

        } catch (error) {
            console.error(`Error checking inventory for ${player.name}: ${error}`);
        }
    }
}, 40); // Runs every 2 seconds (to reduce performance impact)